package com.ruoyi.quartz.task;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.core.websocket.WebSocketServer;
import com.ruoyi.common.enums.CollectTopology;
import com.ruoyi.common.topology.collect.CollectTopologyType;
import com.ruoyi.common.utils.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * @author jianglw
 * @version 1.0
 * @date 2021/4/8 14:25
 */
@Component("topologyTask")
public class TopologyTask {
    @Autowired
    private StringRedisTemplate stringRedisTemplate;
    @Autowired
    WebSocketServer webSocketServer;

    private static final Logger log = LoggerFactory.getLogger( TopologyTask.class );

    /**
     * 无参
     */
    public void topologyParams() {
        log.info( "无参" );
    }

    /**
     * 一个参数
     *
     * @param data
     */
    public void topologyParams(String data) {
        log.info( "一个参数，{}", data );
        if (StringUtils.isNotEmpty( data ) && stringRedisTemplate.hasKey( data )) {
            String top = stringRedisTemplate.opsForValue().get( data );
            JSONObject jsonObject = JSONObject.parseObject( top );
            JSONObject topologyHandle =JSONObject.parseObject( jsonObject.get( "topologyHandle" ).toString() );
            Integer dataAcquisition =topologyHandle.getInteger( "dataAcquisitionMode" );
            /**
             * 获取数据
             */
            CollectTopologyType collectTopologyType=CollectTopology.match( dataAcquisition );
            assert collectTopologyType != null;
            Map<String,Object> stringObjectMap = collectTopologyType.getData( "" );
            /**
             * 配置数据
             */

            /**
             * mqtt与socket
             */
            if (StringUtils.isNotEmpty( jsonObject.getString( "socket" ) )) {
                String webSocket = jsonObject.getString( "socket" );
                try {
                    webSocketServer.sendInfo( "", webSocket.substring( webSocket.lastIndexOf( "/" ), webSocket.length() ) );
                } catch (IOException e) {
                    log.error( "websocket连接失败" );
                    e.printStackTrace();
                }
            } else {

            }
        }
    }

    /**
     * 多个参数
     *
     * @param data
     * @param data1
     * @param data2
     * @param data3
     */
    public void topologyParams(String data, Integer data1, Boolean data2, Double data3) {
        log.info( "多个参数，{},{},{},{}", data, data1, data2, data3 );
    }

}
